CLDFArchive class

Represents a complete CLDF archive

Constructors

CLDFArchive({required Manifest manifest, required List<Location> locations, List<Sector>? sectors, List<Route>? routes, List<Climb>? climbs, List<Session>? sessions, List<Tag>? tags, List<MediaMetadataItem>? mediaItems, Map<String, List<int>>? mediaFiles, Checksums? checksums})
Creates a new CLDFArchive instance

Properties

checksums Checksums?
Checksums for files
final
climbs List<Climb>?
Climbs
final
hasClimbs bool
Check if the archive has climbs
no setter
hasEmbeddedMedia bool
Check if the archive has embedded media files
no setter
hashCode int
The hash code for this object.
no setterinherited
hasMedia bool
Check if the archive has media
no setter
hasRoutes bool
Check if the archive has routes
no setter
hasSectors bool
Check if the archive has sectors
no setter
hasSessions bool
Check if the archive has sessions
no setter
hasTags bool
Check if the archive has tags
no setter
locations List<Location>
Locations
final
manifest Manifest
Archive metadata
final
mediaFilePaths List<String>
Get all media file paths
no setter
mediaFiles Map<String, List<int>>?
Embedded media files (path -> bytes)
final
mediaItems List<MediaMetadataItem>?
Media items
final
routes List<Route>?
Routes
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sectors List<Sector>?
Sectors
final
sessions List<Session>?
Sessions
final
tags List<Tag>?
Tags
final

Methods

getMediaFile(String path) List<int>?
Get media file by path
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited