CLID class

Represents a parsed CLID (CrushLog ID)

Constructors

CLID({required String namespace, required EntityType type, required String uuid, required String fullId, required String shortForm, required String url})
const

Properties

fullId String
final
hashCode int
The hash code for this object.
no setteroverride
namespace String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortForm String
final
type EntityType
final
url String
final
uuid String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override