Location class

Represents a climbing location for CLID generation

Constructors

Location({required String country, String? state, String? city, required String name, required Coordinates coordinates, required bool isIndoor})
const
Location.fromJson(Map<String, dynamic> json)
factory
Location.indoor({required String country, String? state, String? city, required String name, required double lat, required double lon})
factory
Location.outdoor({required String country, String? state, String? city, required String name, required double lat, required double lon})
factory

Properties

city String?
final
coordinates Coordinates
final
country String
final
hashCode int
The hash code for this object.
no setterinherited
isIndoor bool
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited