GradeInfo class
Grade information
- Annotations
-
- @JsonSerializable.new(includeIfNull: false)
Constructors
Properties
-
conversions
→ Map<
String, String> ? -
Grade conversions to other systems
final
- grade → String
-
The grade value
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- system → GradeSystem
-
The grading system used
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this GradeInfo to JSON
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited