MediaSource enum

Source of media

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(valueField: 'value')

Values

local → const MediaSource

File stored locally on device

const MediaSource('local')
cloud → const MediaSource

File stored in cloud (iCloud, Google Photos, etc.)

const MediaSource('cloud')
reference → const MediaSource

Just a reference/URL, not actual file

const MediaSource('reference')
embedded → const MediaSource

Embedded in the archive itself

const MediaSource('embedded')
external → const MediaSource

Legacy values for backward compatibility

const MediaSource('external')
photosLibrary → const MediaSource
const MediaSource('photos_library')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MediaSource>
A constant List of the values in this enum, in order of their declaration.