ProtectionRating enum

Protection rating indicating safety level

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(valueField: 'value')

Values

bombproof → const ProtectionRating

Bombproof protection (extremely safe)

const ProtectionRating('bombproof')
good → const ProtectionRating

Good protection throughout

const ProtectionRating('good')
adequate → const ProtectionRating

Adequate protection but some runouts

const ProtectionRating('adequate')
runout → const ProtectionRating

Runout sections with spaced protection

const ProtectionRating('runout')
serious → const ProtectionRating

Serious consequences for falls

const ProtectionRating('serious')
x → const ProtectionRating

Extremely dangerous with potential for ground falls

const ProtectionRating('x')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ProtectionRating>
A constant List of the values in this enum, in order of their declaration.