RockType enum

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(valueField: 'value')

Values

sandstone → const RockType
const RockType('sandstone')
limestone → const RockType
const RockType('limestone')
granite → const RockType
const RockType('granite')
basalt → const RockType
const RockType('basalt')
gneiss → const RockType
const RockType('gneiss')
quartzite → const RockType
const RockType('quartzite')
conglomerate → const RockType
const RockType('conglomerate')
schist → const RockType
const RockType('schist')
dolomite → const RockType
const RockType('dolomite')
slate → const RockType
const RockType('slate')
rhyolite → const RockType
const RockType('rhyolite')
gabbro → const RockType
const RockType('gabbro')
volcanicTuff → const RockType
const RockType('volcanicTuff')
andesite → const RockType
const RockType('andesite')
chalk → const RockType
const RockType('chalk')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RockType>
A constant List of the values in this enum, in order of their declaration.