Author class

Author information

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Author({String? name, String? email, String? website})
Creates a new Author instance
Author.fromJson(Map<String, dynamic> json)
Creates an Author from JSON
factory

Properties

email String?
Email of the author
final
hashCode int
The hash code for this object.
no setterinherited
name String?
Name of the author
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
website String?
Website URL of the author
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this Author to JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited