DateRange class

Date range for filtered exports

Annotations
  • @JsonSerializable.new()

Constructors

DateRange({required String start, required String end})
Creates a new DateRange instance
DateRange.fromJson(Map<String, dynamic> json)
Creates a DateRange from JSON
factory

Properties

end String
End date
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start String
Start date
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this DateRange to JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited