Manifest class

Metadata about the CLDF archive

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Manifest({required String version, String format = 'CLDF', required DateTime creationDate, required Platform platform, required String appVersion, Author? author, String? source, Stats? stats, ExportConfig? exportOptions})
Creates a new Manifest instance
Manifest.fromJson(Map<String, dynamic> json)
Creates a Manifest from JSON
factory

Properties

appVersion String
Version of the app that created the archive
final
author Author?
Author information
final
creationDate DateTime
When the archive was created
final
exportOptions ExportConfig?
Export configuration
final
format String
Format identifier (always "CLDF")
final
hashCode int
The hash code for this object.
no setterinherited
platform Platform
Platform that created the archive
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String?
Source application or system that created the export
final
stats Stats?
Statistics about exported data
final
version String
CLDF specification version
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this Manifest to JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited