Media class

Media references for climbs

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Media({List<MediaItem>? items, int? count})
Creates a new Media instance
Media.fromJson(Map<String, dynamic> json)
Creates a Media from JSON
factory

Properties

count int?
Total media count
final
hashCode int
The hash code for this object.
no setterinherited
items List<MediaItem>?
List of media items
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this Media to JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited