MediaMetadataItem class

A standalone media item for media-metadata.json file This is different from FlexibleMediaItem which is used inline in climbs

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

MediaMetadataItem({required int id, required MediaType type, required MediaSource source, required String path, String? filename, int? size, String? mimeType, int? width, int? height, int? duration, DateTime? createdAt, MediaCoordinates? coordinates, int? climbId, int? routeId, int? locationId, String? caption, List<String>? tags})
Creates a new MediaMetadataItem instance
MediaMetadataItem.fromJson(Map<String, dynamic> json)
Creates a MediaMetadataItem from JSON
factory

Properties

caption String?
Caption
final
climbId int?
Associated climb ID
final
coordinates MediaCoordinates?
GPS coordinates
final
createdAt DateTime?
Creation date
final
duration int?
Duration in seconds (for videos)
final
filename String?
Original filename
final
hashCode int
The hash code for this object.
no setterinherited
height int?
Height in pixels
final
id int
Unique identifier
final
locationId int?
Associated location ID
final
mimeType String?
MIME type
final
path String
File path or URL
final
routeId int?
Associated route ID
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
File size in bytes
final
source MediaSource
Source of the media
final
tags List<String>?
Associated tags
final
type MediaType
Type of media
final
width int?
Width in pixels
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this MediaMetadataItem to JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited