QROptions class

Options for QR code generation

Constructors

QROptions({String baseUrl = 'https://crushlog.pro', bool includeOfflineData = true, String? ipfsHash, QRFormat format = QRFormat.json})
const

Properties

baseUrl String
final
format QRFormat
final
hashCode int
The hash code for this object.
no setterinherited
includeOfflineData bool
final
ipfsHash String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited