LocationInfo class

Location information from QR code

Constructors

LocationInfo({String? clid, int? id, String? name, String? country, String? state, String? city, bool indoor = false})
LocationInfo.fromJson(Map<String, dynamic> json)
factory

Properties

city String?
final
clid String?
final
country String?
final
hashCode int
The hash code for this object.
no setterinherited
id int?
final
indoor bool
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited