RouteInfo class

Route information from QR code

Constructors

RouteInfo({int? id, String? name, String? grade, String? gradeSystem, String? type, double? height})
RouteInfo.fromJson(Map<String, dynamic> json)
factory

Properties

grade String?
final
gradeSystem String?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
id int?
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited