CLDFWriter class
Writes CLDF archives
Constructors
- CLDFWriter()
- Creates a new CLDFWriter instance
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
writeBytes(
CLDFArchive archive) → Future< List< int> > - Write a CLDF archive to bytes
-
writeFile(
String filePath, CLDFArchive archive) → Future< void> - Write a CLDF archive to a file
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited