CLDFClidAdapter class
Adapter to use CLIDGenerator with main CLDF models
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generateLocationCLID(
Location location) → String - Generate CLID for a CLDF Location
-
generateRouteCLID(
Route route, Location location) → String - Generate CLID for a CLDF Route with its location
-
generateStandaloneRouteCLID(
Route route) → String - Generate CLID for a route without location (uses random UUID v4)