EntityType enum
Entity types for CLDF
Values
- location → const EntityType
-
const EntityType('location') - route → const EntityType
-
const EntityType('route') - sector → const EntityType
-
const EntityType('sector') - climb → const EntityType
-
const EntityType('climb') - session → const EntityType
-
const EntityType('session') - media → const EntityType
-
const EntityType('media')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromString(
String value) → EntityType
Constants
-
values
→ const List<
EntityType> - A constant List of the values in this enum, in order of their declaration.