Route class

Represents a climbing route for CLID generation

Constructors

Route({required String name, required String grade, FirstAscent? firstAscent, double? height})
const
Route.fromJson(Map<String, dynamic> json)
factory

Properties

firstAscent FirstAscent?
final
grade String
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited