Climb class
A single climbing attempt or completion
- Annotations
-
- @JsonSerializable.new(includeIfNull: false)
Constructors
-
Climb({required int id, String? clid, int? sessionId, int? routeId, String? routeClid, required String date, String? time, String? routeName, GradeInfo? grades, required ClimbType type, required FinishType finishType, int attempts = 1, int repeats = 0, bool isRepeat = false, BelayType? belayType, int? duration, int? falls, double? height, int? rating, String? notes, List<
String> ? tags, String? beta, Media? media, String? color, RockType? rockType, TerrainType? terrainType, bool? isIndoor, List<String> ? partners, String? weather, Map<String, dynamic> ? customFields}) - Creates a new Climb instance
-
Climb.fromJson(Map<
String, dynamic> json) -
Creates a Climb from JSON
factory
Properties
- attempts → int
-
Number of attempts
final
- belayType → BelayType?
-
Belay type for rope climbs
final
- beta → String?
-
Beta information
final
- clid → String?
-
CrushLog ID - globally unique identifier (v1.3.0+)
final
- color → String?
-
Hold color
final
-
customFields
→ Map<
String, dynamic> ? -
Custom fields
final
- date → String
-
Date of the climb (YYYY-MM-DD)
final
- duration → int?
-
Duration in minutes
final
- falls → int?
-
Number of falls
final
- finishType → FinishType
-
How the climb was finished
final
- grades → GradeInfo?
-
Grade information
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
Height in meters
final
- id → int
-
Unique identifier
final
- isIndoor → bool?
-
Whether this was indoor
final
- isRepeat → bool
-
Whether this is a repeat
final
- media → Media?
-
Media references
final
- notes → String?
-
Notes
final
-
partners
→ List<
String> ? -
Climbing partners
final
- rating → int?
-
Quality rating (0-5)
final
- repeats → int
-
Number of repeats
final
- rockType → RockType?
-
Rock type
final
- routeClid → String?
-
CrushLog ID of the route - globally unique identifier for server matching (v1.4.0+)
final
- routeId → int?
-
Reference to route by ID (internal file reference)
final
- routeName → String?
-
Name of the route (when route is not in database)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → int?
-
Reference to session
final
-
Associated tags
final
- terrainType → TerrainType?
-
Terrain type
final
- time → String?
-
Time of the climb (HH:MM:SS)
final
- type → ClimbType
-
Type of climb
final
- weather → String?
-
Weather conditions
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this Climb to JSON
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited