FinishType enum
Values
- flash → const FinishType
-
const FinishType('flash') - top → const FinishType
-
const FinishType('top') - onsight → const FinishType
-
const FinishType('onsight') - redpoint → const FinishType
-
const FinishType('redpoint') - repeat → const FinishType
-
const FinishType('repeat') - project → const FinishType
-
const FinishType('project') - attempt → const FinishType
-
const FinishType('attempt')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isBoulderFinish → bool
-
Check if this is a boulder-specific finish type
no setter
- isRouteFinish → bool
-
Check if this is a route-specific finish type
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
isValidForClimbType(
ClimbType climbType) → bool - Check if this finish type is valid for the given climb type
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FinishType> - A constant List of the values in this enum, in order of their declaration.