MediaDesignation enum
Purpose or type of media content
Values
- topo → const MediaDesignation
-
const MediaDesignation('topo') - beta → const MediaDesignation
-
const MediaDesignation('beta') - approach → const MediaDesignation
-
const MediaDesignation('approach') - log → const MediaDesignation
-
const MediaDesignation('log') - overview → const MediaDesignation
-
const MediaDesignation('overview') - conditions → const MediaDesignation
-
const MediaDesignation('conditions') - gear → const MediaDesignation
-
const MediaDesignation('gear') - descent → const MediaDesignation
-
const MediaDesignation('descent') - other → const MediaDesignation
-
const MediaDesignation('other')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
String? value) → MediaDesignation - Parse from string value, defaulting to 'other' if unknown
Constants
-
values
→ const List<
MediaDesignation> - A constant List of the values in this enum, in order of their declaration.