Grades class
Strongly typed grades with enum keys
- Annotations
-
- @JsonSerializable.new(includeIfNull: false)
Constructors
Properties
- font → String?
-
Fontainebleau bouldering grade
final
- french → String?
-
French sport climbing grade
final
- hasGrades → bool
-
Check if any grades are present
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uiaa → String?
-
UIAA grade
final
- vScale → String?
-
V-Scale grade (bouldering)
final
- yds → String?
-
Yosemite Decimal System grade
final
Methods
-
copyWith(
{String? vScale, String? yds, String? french, String? font, String? uiaa}) → Grades - Create a copy with updated fields
-
getGrade(
String system) → String? - Get grade by system name
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setGrade(
String system, String grade) → Grades - Set grade for a specific system
-
toJson(
) → Map< String, dynamic> -
toMap(
) → Map< String, String> - Convert to simplified Map format for backwards compatibility
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited