Location class
A climbing location (crag, gym, etc.)
- Annotations
-
- @JsonSerializable.new(includeIfNull: false)
Constructors
-
Location({required int id, String? clid, required String name, required bool isIndoor, String? country, String? state, String? city, String? address, Coordinates? coordinates, bool starred = false, RockType? rockType, TerrainType? terrainType, String? accessInfo, Media? media, DateTime? createdAt, Map<
String, dynamic> ? customFields}) - Creates a new Location instance
-
Location.fromJson(Map<
String, dynamic> json) -
Creates a Location from JSON
factory
Properties
- accessInfo → String?
-
Access information
final
- address → String?
-
Full address
final
- city → String?
-
City
final
- clid → String?
-
CrushLog ID - globally unique identifier (v1.3.0+)
final
- coordinates → Coordinates?
-
GPS coordinates
final
- country → String?
-
Country
final
- createdAt → DateTime?
-
Creation timestamp
final
-
customFields
→ Map<
String, dynamic> ? -
Custom fields
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
Unique identifier
final
- isIndoor → bool
-
Whether this is an indoor location
final
- media → Media?
-
Media associated with this location (overview, approach photos, etc.)
final
- name → String
-
Location name
final
- rockType → RockType?
-
Type of rock
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- starred → bool
-
Whether this location is marked as favorite
final
- state → String?
-
State or province
final
- terrainType → TerrainType?
-
Type of terrain
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this Location to JSON
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited