ExportConfig class
Export configuration
- Annotations
-
- @JsonSerializable.new(includeIfNull: false)
Constructors
- ExportConfig({bool includeMedia = false, String? mediaStrategy, DateRange? dateRange})
- Creates a new ExportConfig instance
-
ExportConfig.fromJson(Map<
String, dynamic> json) -
Creates a ExportConfig from JSON
factory
Properties
- dateRange → DateRange?
-
Date range for filtered exports
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeMedia → bool
-
Whether to include media files
final
- mediaStrategy → String?
-
Media export strategy
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this ExportConfig to JSON
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited