Stats class
Statistics about exported data
- Annotations
-
- @JsonSerializable.new(includeIfNull: false)
Constructors
Properties
- climbsCount → int?
-
Number of climbs in the export
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- locationsCount → int?
-
Number of locations in the export
final
- mediaCount → int?
-
Number of media items in the export
final
- routesCount → int?
-
Number of routes in the export
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sectorsCount → int?
-
Number of sectors in the export
final
- sessionsCount → int?
-
Number of sessions in the export
final
-
Number of tags in the export
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this Stats to JSON
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited