Route class
A climbing route or boulder problem
- Annotations
-
- @JsonSerializable.new(includeIfNull: false)
Constructors
-
Route({required int id, String? clid, required int locationId, int? sectorId, required String name, required RouteType routeType, RouteCharacteristics? routeCharacteristics, Map<
String, String> ? grades, double? height, String? color, FirstAscent? firstAscent, ProtectionRating? protectionRating, int? qualityRating, String? beta, String? gearNotes, List<String> ? tags, Media? media, QrCode? qrCode, DateTime? createdAt, DateTime? updatedAt, Map<String, dynamic> ? customFields}) - Creates a new Route instance
-
Route.fromJson(Map<
String, dynamic> json) -
Creates a Route from JSON
factory
Properties
- beta → String?
-
Beta information
final
- clid → String?
-
CrushLog ID - globally unique identifier (v1.3.0+)
final
- color → String?
-
Hold color
final
- createdAt → DateTime?
-
When the route was created
final
-
customFields
→ Map<
String, dynamic> ? -
Custom fields
final
- firstAscent → FirstAscent?
-
First ascent information
final
- gearNotes → String?
-
Specific gear requirements or protection notes
final
-
grades
→ Map<
String, String> ? -
Grades in different systems
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
Height in meters
final
- id → int
-
Unique identifier
final
- locationId → int
-
Reference to location
final
- media → Media?
-
Media associated with this route (topos, beta videos, etc.)
final
- name → String
-
Route name
final
- protectionRating → ProtectionRating?
-
Protection rating
final
- qrCode → QrCode?
-
QR code data for physical route marking (v1.3.0+)
final
- qualityRating → int?
-
Quality rating (0-5)
final
- routeCharacteristics → RouteCharacteristics?
-
Route protection characteristics (trad, bolted)
final
- routeType → RouteType
-
Type of route
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sectorId → int?
-
Reference to sector
final
-
Associated tags
final
- updatedAt → DateTime?
-
When the route was last updated
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this Route to JSON
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited