Sector class
A sector within a climbing location
- Annotations
-
- @JsonSerializable.new(includeIfNull: false)
Constructors
- Sector({required int id, String? clid, required int locationId, required String name, bool isDefault = false, String? description, String? approach, Coordinates? coordinates, Media? media, DateTime? createdAt})
- Creates a new Sector instance
-
Sector.fromJson(Map<
String, dynamic> json) -
Creates a Sector from JSON
factory
Properties
- approach → String?
-
Approach information
final
- clid → String?
-
CrushLog ID - globally unique identifier (v1.3.0+)
final
- coordinates → Coordinates?
-
GPS coordinates
final
- createdAt → DateTime?
-
Creation timestamp
final
- description → String?
-
Description
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
Unique identifier
final
- isDefault → bool
-
Whether this is the default sector for the location
final
- locationId → int
-
Reference to location
final
- media → Media?
-
Media associated with this sector (overview photos, approach maps, etc.)
final
- name → String
-
Sector name
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this Sector to JSON
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited