Tag class
A tag for categorization
- Annotations
-
- @JsonSerializable.new(includeIfNull: false)
Constructors
Properties
- category → String?
-
Tag category
final
- color → String?
-
Associated color (hex format)
final
- fullName → String
-
Get the full tag reference (category:name)
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
Unique identifier
final
- isPredefined → bool
-
Whether this is a system-defined tag
final
- name → String
-
Tag name/value
final
- predefinedTagKey → String?
-
Key for predefined tags
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this Tag to JSON
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited