QRCodeData class
QR code data payload (v1 spec with CLIDs)
Constructors
Properties
- cldf → String?
-
final
- clid → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
loc
→ Map<
String, dynamic> ? -
final
-
meta
→ Map<
String, dynamic> ? -
final
-
route
→ Map<
String, dynamic> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String?
-
final
-
verification
→ Map<
String, dynamic> ? -
final
- version → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited