QRGenerator class
Generates QR codes for routes and locations
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generateLocationData(
Location location, QROptions options) → QRCodeData - Generate QR code data for a location
-
generatePNG(
QRCodeData data, QROptions options, {int size = 256, int foregroundColor = 0xFF000000, int backgroundColor = 0xFFFFFFFF}) → Future< Uint8List> - Generate QR code image as PNG bytes
-
generateRouteData(
Route route, QROptions options, {Location? location}) → QRCodeData - Generate QR code data for a route
-
generateSVG(
QRCodeData data, QROptions options, {int size = 256, String foregroundColor = '#000000', String backgroundColor = '#FFFFFF'}) → String - Generate QR code as SVG string
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited