QRScanner class
QR code scanner for CLDF data
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
String data) → ParsedQRData? - Parse QR code data from string
-
scanImage(
Uint8List imageBytes) → Future< ParsedQRData?> - Scan QR code from image bytes (PNG, JPEG, etc.)
-
toLocation(
ParsedQRData data) → Location? - Convert parsed QR data to Location object
-
toRoute(
ParsedQRData data) → Route? - Convert parsed QR data to Route object
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited